summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/tests/Notify/lib/EventChannel_Command.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/tests/Notify/lib/EventChannel_Command.h')
-rw-r--r--TAO/orbsvcs/tests/Notify/lib/EventChannel_Command.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/TAO/orbsvcs/tests/Notify/lib/EventChannel_Command.h b/TAO/orbsvcs/tests/Notify/lib/EventChannel_Command.h
index 3f2c7720121..3323f380af6 100644
--- a/TAO/orbsvcs/tests/Notify/lib/EventChannel_Command.h
+++ b/TAO/orbsvcs/tests/Notify/lib/EventChannel_Command.h
@@ -76,11 +76,11 @@ protected:
CosNotification::AdminProperties admin_;
- /// Flag to tell if the Channel Factory should be colocated.
- CORBA::Boolean colocated_;
+ /// Flag to tell if the Channel Factory should be collocated.
+ CORBA::Boolean collocated_;
- /// Helper method to create a colocated ECF.
- void create_colocated_ecf (ACE_ENV_SINGLE_ARG_DECL);
+ /// Helper method to create a collocated ECF.
+ void create_collocated_ecf (ACE_ENV_SINGLE_ARG_DECL);
/// = Handlers
void handle_create (ACE_ENV_SINGLE_ARG_DECL);